pub struct IdentityGate<F: Field> {
layer_id: LayerId,
wiring: Vec<(u32, u32)>,
source_mle: DenseMle<F>,
beta_g2_vec: Option<Vec<BetaValues<F>>>,
g1_challenges_vec: Option<Vec<Vec<F>>>,
challenges_vec: Option<Vec<Vec<F>>>,
a_hg_mle_phase_1: Option<DenseMle<F>>,
total_num_vars: usize,
num_dataparallel_vars: usize,
}Expand description
The Identity Gate struct allows being able to select specific indices
from the source_mle that are not necessarily regular.
Fields
layer_id: LayerIdLayer ID for this gate.
wiring: Vec<(u32, u32)>Wiring tuples are of the form (dest_idx, src_idx), which specifies
that we would like the value in the src_idx of the source_mle to
be copied into dest_idx of the output MLE.
source_mle: DenseMle<F>The MLE from which we are selecting the indices.
beta_g2_vec: Option<Vec<BetaValues<F>>>The BetaValues struct which enumerates the incoming claim’s challenge points on the dataparallel vars of the MLE.
g1_challenges_vec: Option<Vec<Vec<F>>>The nondataparallel claim points in the layer.
challenges_vec: Option<Vec<Vec<F>>>The claim points in the layer (both nondataparallel and dataparallel) challenges.
a_hg_mle_phase_1: Option<DenseMle<F>>The MLE initialized in phase 1, which contains the beta values over
g1_challenges folded into the wiring function.
total_num_vars: usizeThe total number of variables in the layer.
num_dataparallel_vars: usizeThe number of vars representing the number of “dataparallel” copies of the circuit.
Implementations
Sourceimpl<F: Field> IdentityGate<F>
impl<F: Field> IdentityGate<F>
Sourcepub fn new(
layer_id: LayerId,
wiring: Vec<(u32, u32)>,
mle: DenseMle<F>,
total_num_vars: usize,
num_dataparallel_vars: usize,
) -> IdentityGate<F>
pub fn new( layer_id: LayerId, wiring: Vec<(u32, u32)>, mle: DenseMle<F>, total_num_vars: usize, num_dataparallel_vars: usize, ) -> IdentityGate<F>
Create a new IdentityGate struct.
fn append_leaf_mles_to_transcript( &self, transcript_writer: &mut impl ProverTranscript<F>, )
Sourcefn init_phase_1(&mut self, challenge: &[F], fully_bound_beta_g2: F)
fn init_phase_1(&mut self, challenge: &[F], fully_bound_beta_g2: F)
Initialize the bookkeeping table necessary for phase 1, which is the binding of the non-dataparallel variables in the source MLE. This is the initialization function used when we are doing interpolative claim aggregation.
For the random coefficients, we simply use the fully bound value of beta_g2 since this is the value that scales all of the sumcheck evaluations.
Sourcefn init_phase_1_rlc(&mut self, challenges: &[&[F]], random_coefficients: &[F])
fn init_phase_1_rlc(&mut self, challenges: &[&[F]], random_coefficients: &[F])
Initialize the bookkeeping table necessary for phase 1, which is the binding of the non-dataparallel variables in the source MLE. This is the initialization function used when we are doing RLC claim aggregation.