pub struct IdentityGateLayerDescription<F: Field> {
id: LayerId,
wiring: Vec<(u32, u32)>,
source_mle: MleDescription<F>,
total_num_vars: usize,
num_dataparallel_vars: usize,
}Expand description
The circuit Description for an IdentityGate.
Fields
id: LayerIdThe layer id associated with this gate layer.
wiring: Vec<(u32, u32)>A vector of tuples representing the “nonzero” gates, especially useful in the sparse case the format is (z, x) where the gate at label z is the output of adding all values from labels x.
source_mle: MleDescription<F>The source MLE of the expression, i.e. the mle that makes up the “x” variables.
total_num_vars: usizeThe total number of variables in the layer.
num_dataparallel_vars: usizeThe number of vars representing the number of “dataparallel” copies of the circuit.
Implementations
Sourceimpl<F: Field> IdentityGateLayerDescription<F>
impl<F: Field> IdentityGateLayerDescription<F>
Sourcepub fn new(
id: LayerId,
wiring: Vec<(u32, u32)>,
source_mle: MleDescription<F>,
total_num_vars: usize,
num_dataparallel_vars: Option<usize>,
) -> Self
pub fn new( id: LayerId, wiring: Vec<(u32, u32)>, source_mle: MleDescription<F>, total_num_vars: usize, num_dataparallel_vars: Option<usize>, ) -> Self
Constructor for IdentityGateLayerDescription. Arguments:
id: The layer id associated with this layer.source_mle: The Mle that is being routed to this layer.nonzero_gates: A list of tuples representing the gates that are nonzero, in the form(dest_idx, src_idx).total_num_vars: The total number of variables in the layer.num_dataparallel_vars: The number of dataparallel variables to use in this layer.